pyqstrat — pyqstrat 0.1.0 documentation

# pyqstrat

- pyqstrat package
  - Submodules
  - pyqstrat.pq_utils module
  - pyqstrat.pq_types module
  - pyqstrat.holiday_calendars module
  - pyqstrat.account module
  - pyqstrat.strategy module
  - pyqstrat.portfolio module
  - pyqstrat.optimize module
  - pyqstrat.plot module
  - pyqstrat.evaluator module
  - pyqstrat.pyqstrat_cpp module
  - pyqstrat.pyqstrat_io module
  - pyqstrat.trade_bars module
  - pyqstrat.interactive_plot module
  - pyqstrat.markets module
  - Module contents